@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 
 from .comms import printer
-from .core import elastic_bulk
-from .core import elastic_2D
 from .parsers import VaspOutcar
 from .core import ElasticProperties
 from .core import ElasticProperties2D
