@@ -719,8 +719,60 @@ class ElasticProperties:
             "\nMelting temperature calculated from empirical relation: Tm = 607 + 9.3*Kvrh \pm 555 (in K)"
         )
         print("Tm (in K)=  %10.5f (plus-minus 555 K) " % self.melting_temperature)
-        print("----------------------------------------------- ")
+        print("------------------------------------------------------------------ ")
+
+        print("Hardness analysis from 6 different semi-empirical relationships.")
+        H1a, H1b, H2, H3, H4, H5 = self.hardness
+        print("------------------------------------------------------------------ ")
+        print("Hardness (H1a) =", "{:.2f}".format(H1a), "GPa", "  Ref.[1]")
+        print("Hardness (H1b) =", "{:.2f}".format(H1b), "GPa", "  Ref.[1]")
+        print("Hardness (H2)  =", "{:.2f}".format(H2), "GPa", "  Ref.[2]")
+        print("Hardness (H3)  =", "{:.2f}".format(H3), "GPa", "  Ref.[3]")
+        print("Hardness (H4)  =", "{:.2f}".format(H4), "GPa", "  Ref.[4]")
+        print("Hardness (H5)  =", "{:.2f}".format(H5), "GPa", "  Ref.[5]")
+        print("References:")
+        print(
+            "[1] Correlation between hardness and elastic moduli of the covalent crystals. Jiang, et al. (2011)."
+        )
+        print(
+            "[2] Computational alchemy: the search for new superhard materials. Teter (1998)."
+        )
+        print(
+            "[3] Mechanical and electronic properties of B12-based ternary crystals of orthorhombic phase. Jiang et al. (2010)."
+        )
+        print(
+            "[4] Theoretical investigation on the transition-metal borides with Ta3B4-type structure: A class of hard and refractory materials. Miao et al. (2011)."
+        )
+        print(
+            "[5] Modeling hardness of polycrystalline materials and bulk metallic glasses. Chen et al. (2011)."
+        )
 
     @property
     def elastic_stability(self):
         return eigenvals.positive_evals(self.elastic_tensor)
+
+    @property
+    def hardness(self):
+        """
+        Returns
+        -------
+        float
+            The hardness calculated by 6 different methods:
+            [H1a and H1b] Correlation between hardness and elastic moduli of the covalent crystals. Jiang, et al. (2011).
+            [H2] Computational alchemy: the search for new superhard materials. Teter (1998).
+            [H3] Mechanical and electronic properties of B12-based ternary crystals of orthorhombic phase. Jiang et al. (2010).
+            [H4] Theoretical investigation on the transition-metal borides with Ta3B4-type structure: A class of hard and refractory materials. Miao et al. (2011).
+            [H5] Modeling hardness of polycrystalline materials and bulk metallic glasses. Chen et al. (2011).
+        """
+        B = self.K_vrh
+        G = self.G_vrh
+        Y = self.E_vrh
+        v = self.Nu_vrh
+        k = G / B
+        H1a = (1 / 6.78) * G
+        H1b = (1 / 16.48) * Y
+        H2 = (0.1769 * G) - 2.899
+        H3 = (1 / 15.76) * Y
+        H4 = ((1 - 2 * v) * B) / (6 * (1 + v))
+        H5 = 2 * ((k * k * G) ** 0.585) - 3
+        return H1a, H1b, H2, H3, H4, H5
